searchData={"items":[{"type":"module","title":"FeatureFlipper","doc":"Main interface for feature flag operations.\n\nFeatureFlipper provides a comprehensive, easy-to-integrate feature flag system\nfor Elixir applications with Consul integration, caching, and deadline management.","ref":"FeatureFlipper.html"},{"type":"module","title":"Configuration - FeatureFlipper","doc":"# config/config.exs\n    config :feature_flipper,\n      consul_kv_path: \"telephony/services/routing\",\n      consul_client_http_addr: \"http://consul.query.dev.telnyx.io:18500\",\n      env: System.get_env(\"ENV\", \"dev\"),\n      hostname: System.get_env(\"SERVER_HOSTNAME\", \"local\"),\n      version_suffix: \"1.7.9-rc\"  # Optional, for production versioning","ref":"FeatureFlipper.html#module-configuration"},{"type":"module","title":"Usage - FeatureFlipper","doc":"# Define feature flippers\n    defmodule MyApp.FeatureFlippers do\n      use FeatureFlipper.Definition\n\n      define_flipper :use_warehouse_cache_tbs_2221?, %{\n        deadline: ~D[2025-06-30],\n        description: \"Use warehouse cache for improved performance\"\n      }\n    end\n\n    # Use feature flippers\n    if MyApp.FeatureFlippers.use_warehouse_cache_tbs_2221?() do\n      # Feature is enabled\n    end\n\n    # Or use the main interface\n    if FeatureFlipper.enabled?(:use_warehouse_cache_tbs_2221?) do\n      # Feature is enabled\n    end","ref":"FeatureFlipper.html#module-usage"},{"type":"function","title":"FeatureFlipper.check_deadlines/0","doc":"Check for feature flippers that are past their deadline.\n\nReturns a list of warning messages for features that are past their deadline.","ref":"FeatureFlipper.html#check_deadlines/0"},{"type":"function","title":"Examples - FeatureFlipper.check_deadlines/0","doc":"iex> FeatureFlipper.check_deadlines()\n    [\"Feature 'old_feature' is past its deadline of 2024-01-01\"]\n\n    iex> FeatureFlipper.check_deadlines()\n    []","ref":"FeatureFlipper.html#check_deadlines/0-examples"},{"type":"function","title":"FeatureFlipper.enabled?/1","doc":"Check if a feature flipper is enabled.","ref":"FeatureFlipper.html#enabled?/1"},{"type":"function","title":"Parameters - FeatureFlipper.enabled?/1","doc":"* `flipper_name` - The name of the feature flipper (atom or string)","ref":"FeatureFlipper.html#enabled?/1-parameters"},{"type":"function","title":"Examples - FeatureFlipper.enabled?/1","doc":"iex> FeatureFlipper.enabled?(:my_feature)\n    true\n\n    iex> FeatureFlipper.enabled?(\"my_feature\")\n    false","ref":"FeatureFlipper.html#enabled?/1-examples"},{"type":"function","title":"FeatureFlipper.get_all_flags/0","doc":"Get all feature flags and their current values.","ref":"FeatureFlipper.html#get_all_flags/0"},{"type":"function","title":"Examples - FeatureFlipper.get_all_flags/0","doc":"iex> FeatureFlipper.get_all_flags()\n    %{\n      my_feature: true,\n      another_feature: false\n    }","ref":"FeatureFlipper.html#get_all_flags/0-examples"},{"type":"function","title":"FeatureFlipper.reload_configuration/0","doc":"Reload configuration from Consul.\n\nThis function fetches the latest feature flipper configuration from Consul\nand updates the local cache.","ref":"FeatureFlipper.html#reload_configuration/0"},{"type":"function","title":"Examples - FeatureFlipper.reload_configuration/0","doc":"iex> FeatureFlipper.reload_configuration()\n    :ok\n\n    iex> FeatureFlipper.reload_configuration()\n    {:error, :consul_unavailable}","ref":"FeatureFlipper.html#reload_configuration/0-examples"},{"type":"module","title":"FeatureFlipper.Config","doc":"Define the accepted config values for the feature flipper","ref":"FeatureFlipper.Config.html"},{"type":"function","title":"FeatureFlipper.Config.config/1","doc":"","ref":"FeatureFlipper.Config.html#config/1"},{"type":"function","title":"FeatureFlipper.Config.valid?/1","doc":"","ref":"FeatureFlipper.Config.html#valid?/1"},{"type":"function","title":"FeatureFlipper.Config.valid?/2","doc":"","ref":"FeatureFlipper.Config.html#valid?/2"},{"type":"module","title":"FeatureFlipper.ConfigLoader","doc":"Handles loading and caching of feature flipper configuration from Consul.","ref":"FeatureFlipper.ConfigLoader.html"},{"type":"function","title":"FeatureFlipper.ConfigLoader.get_all_flags/0","doc":"Get all feature flags and their current values.","ref":"FeatureFlipper.ConfigLoader.html#get_all_flags/0"},{"type":"function","title":"FeatureFlipper.ConfigLoader.get_flipper_value/3","doc":"Get the value of a feature flipper.","ref":"FeatureFlipper.ConfigLoader.html#get_flipper_value/3"},{"type":"function","title":"FeatureFlipper.ConfigLoader.init/0","doc":"Initialize the ConfigLoader with configuration.","ref":"FeatureFlipper.ConfigLoader.html#init/0"},{"type":"function","title":"FeatureFlipper.ConfigLoader.register_flippers/1","doc":"Register flippers from a definition module.","ref":"FeatureFlipper.ConfigLoader.html#register_flippers/1"},{"type":"function","title":"FeatureFlipper.ConfigLoader.reload_configuration/0","doc":"Reload configuration from Consul.","ref":"FeatureFlipper.ConfigLoader.html#reload_configuration/0"},{"type":"module","title":"FeatureFlipper.ConsulClient","doc":"HTTP client for interacting with Consul KV store.","ref":"FeatureFlipper.ConsulClient.html"},{"type":"function","title":"FeatureFlipper.ConsulClient.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#delete/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#delete!/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#get/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#get!/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.get_feature_flippers/1","doc":"Get feature flipper data from Consul KV store.","ref":"FeatureFlipper.ConsulClient.html#get_feature_flippers/1"},{"type":"function","title":"FeatureFlipper.ConsulClient.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#head/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#head!/3"},{"type":"type","title":"FeatureFlipper.ConsulClient.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"FeatureFlipper.ConsulClient.html#t:option/0"},{"type":"function","title":"FeatureFlipper.ConsulClient.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#options/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#options!/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"FeatureFlipper.ConsulClient.html#patch/4"},{"type":"function","title":"FeatureFlipper.ConsulClient.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"FeatureFlipper.ConsulClient.html#patch!/4"},{"type":"function","title":"FeatureFlipper.ConsulClient.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"FeatureFlipper.ConsulClient.html#post/4"},{"type":"function","title":"FeatureFlipper.ConsulClient.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"FeatureFlipper.ConsulClient.html#post!/4"},{"type":"function","title":"FeatureFlipper.ConsulClient.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"FeatureFlipper.ConsulClient.html#put/4"},{"type":"function","title":"FeatureFlipper.ConsulClient.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"FeatureFlipper.ConsulClient.html#put!/4"},{"type":"function","title":"FeatureFlipper.ConsulClient.request/2","doc":"Perform a request.","ref":"FeatureFlipper.ConsulClient.html#request/2"},{"type":"function","title":"Options - FeatureFlipper.ConsulClient.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyword list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"FeatureFlipper.ConsulClient.html#request/2-options"},{"type":"function","title":"Examples - FeatureFlipper.ConsulClient.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#request/2-examples"},{"type":"function","title":"FeatureFlipper.ConsulClient.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"FeatureFlipper.ConsulClient.html#request!/2"},{"type":"function","title":"FeatureFlipper.ConsulClient.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#trace/3"},{"type":"function","title":"FeatureFlipper.ConsulClient.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"FeatureFlipper.ConsulClient.html#trace!/3"},{"type":"module","title":"FeatureFlipper.DeadlineChecker","doc":"Handles deadline checking for feature flippers.","ref":"FeatureFlipper.DeadlineChecker.html"},{"type":"function","title":"FeatureFlipper.DeadlineChecker.check_deadlines/0","doc":"Check for feature flippers that are past their deadline.\n\nReturns a list of warning messages for features that are past their deadline.","ref":"FeatureFlipper.DeadlineChecker.html#check_deadlines/0"},{"type":"function","title":"FeatureFlipper.DeadlineChecker.check_flipper_deadline/2","doc":"Check if a specific flipper is past its deadline.","ref":"FeatureFlipper.DeadlineChecker.html#check_flipper_deadline/2"},{"type":"function","title":"FeatureFlipper.DeadlineChecker.days_until_deadline/1","doc":"Get days until deadline for a flipper.","ref":"FeatureFlipper.DeadlineChecker.html#days_until_deadline/1"},{"type":"function","title":"FeatureFlipper.DeadlineChecker.expiring_soon/1","doc":"Get flippers that will expire within the specified number of days.","ref":"FeatureFlipper.DeadlineChecker.html#expiring_soon/1"},{"type":"module","title":"FeatureFlipper.Definition","doc":"DSL for defining feature flippers.\n\nThis module provides macros for defining feature flippers with metadata\nand automatically generates functions for each defined flipper.","ref":"FeatureFlipper.Definition.html"},{"type":"module","title":"Usage - FeatureFlipper.Definition","doc":"defmodule MyApp.FeatureFlippers do\n      use FeatureFlipper.Definition\n\n      define_flipper :use_warehouse_cache_tbs_2221?, %{\n        deadline: ~D[2025-06-30],\n        description: \"Use warehouse cache for improved performance\"\n      }\n\n      define_flipper :enable_warehouse_cache_mirroring_tbs_2395?, %{\n        deadline: ~D[2025-06-30],\n        force_disable: false,\n        description: \"Enable cache mirroring for data consistency\"\n      }\n\n      define_flipper :user_rate_tariff_manager_tbs_2873?, %{\n        deadline: ~D[2025-06-30],\n        key: \"custom_tariff_key\",  # Optional custom Consul key\n        description: \"Use new tariff manager for user rates\"\n      }\n    end\n\nThis will automatically generate functions:\n- `MyApp.FeatureFlippers.use_warehouse_cache_tbs_2221?()`\n- `MyApp.FeatureFlippers.enable_warehouse_cache_mirroring_tbs_2395?()`\n- `MyApp.FeatureFlippers.user_rate_tariff_manager_tbs_2873?()`","ref":"FeatureFlipper.Definition.html#module-usage"},{"type":"macro","title":"FeatureFlipper.Definition.__using__/1","doc":"Use this module to enable the feature flipper DSL.","ref":"FeatureFlipper.Definition.html#__using__/1"},{"type":"macro","title":"FeatureFlipper.Definition.define_flipper/2","doc":"Define a feature flipper with metadata.","ref":"FeatureFlipper.Definition.html#define_flipper/2"},{"type":"macro","title":"Parameters - FeatureFlipper.Definition.define_flipper/2","doc":"* `name` - The name of the feature flipper (atom)\n  * `metadata` - A map containing flipper metadata","ref":"FeatureFlipper.Definition.html#define_flipper/2-parameters"},{"type":"macro","title":"Metadata Options - FeatureFlipper.Definition.define_flipper/2","doc":"* `:deadline` - Date when the feature should be removed (Date struct)\n  * `:description` - Human-readable description of the feature\n  * `:force_disable` - Force disable in non-production environments (boolean, default: false)\n  * `:key` - Custom Consul key (string, optional)","ref":"FeatureFlipper.Definition.html#define_flipper/2-metadata-options"},{"type":"macro","title":"Examples - FeatureFlipper.Definition.define_flipper/2","doc":"define_flipper :my_feature, %{\n      deadline: ~D[2025-06-30],\n      description: \"My awesome feature\",\n      force_disable: false\n    }","ref":"FeatureFlipper.Definition.html#define_flipper/2-examples"},{"type":"extras","title":"FeatureFlipper","doc":"# FeatureFlipper\n\nA comprehensive, easy-to-integrate feature flag system for Elixir applications with Consul integration, caching, and deadline management.","ref":"readme.html"},{"type":"extras","title":"Features - FeatureFlipper","doc":"- **Simple Configuration Interface**: Easy setup with minimal configuration\n- **Feature Definition DSL**: Clean, declarative syntax for defining feature flags\n- **Automatic Function Generation**: Generates functions for each defined feature flipper\n- **Environment-Aware Logic**: Different behavior for production vs non-production environments\n- **Consul Integration**: Seamless integration with Consul KV store\n- **Caching Layer**: High-performance in-memory caching with `:persistent_term`\n- **Configuration Management**: Runtime configuration reloading\n- **Deadline Management**: Automatic deadline checking and warnings","ref":"readme.html#features"},{"type":"extras","title":"Installation - FeatureFlipper","doc":"Add `feature_flipper` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:feature_flipper, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - FeatureFlipper","doc":"Add configuration to your `config/config.exs`:\n\n```elixir\nconfig :feature_flipper,\n  consul_kv_path: \"telephony/services/routing\",\n  consul_client_http_addr: \"http://consul.query.dev.telnyx.io:18500\",\n  env: System.get_env(\"ENV\", \"dev\"),\n  hostname: System.get_env(\"SERVER_HOSTNAME\", \"local\"),\n  cache_name: :feature_flipper_cache,\n  version_suffix: \"1.7.9-rc\"  # Optional, for production versioning\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - FeatureFlipper","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"1. Add it as a start phase - FeatureFlipper","doc":"```elixir\n# lib/my_app/application.ex\ndef start_phase(:get_feature_flippers) do\n  FeatureFlipper.ConfigLoader.init()\nend\n```","ref":"readme.html#1-add-it-as-a-start-phase"},{"type":"extras","title":"2. Define feature flippers - FeatureFlipper","doc":"```elixir\n# lib/my_app/feature_flippers.ex\ndefmodule MyApp.FeatureFlippers do\n  use FeatureFlipper.Definition\n\n  define_flipper :use_warehouse_cache_tbs_2221?, %{\n    deadline: ~D[2025-06-30],\n    description: \"Use warehouse cache for improved performance\"\n  }\n\n  define_flipper :enable_warehouse_cache_mirroring_tbs_2395?, %{\n    deadline: ~D[2025-06-30],\n    force_disable: false,\n    description: \"Enable cache mirroring for data consistency\"\n  }\n\n  define_flipper :user_rate_tariff_manager_tbs_2873?, %{\n    deadline: ~D[2025-06-30],\n    key: \"custom_tariff_key\",  # Optional custom Consul key\n    description: \"Use new tariff manager for user rates\"\n  }\nend\n```","ref":"readme.html#2-define-feature-flippers"},{"type":"extras","title":"3. Use feature flippers in your code - FeatureFlipper","doc":"```elixir\n# Using generated functions (recommended)\nif MyApp.FeatureFlippers.use_warehouse_cache_tbs_2221?() do\n  # Feature is enabled\n  use_warehouse_cache()\nelse\n  # Feature is disabled\n  use_regular_cache()\nend\n\n# Using the main interface\nif FeatureFlipper.enabled?(:use_warehouse_cache_tbs_2221?) do\n  # Feature is enabled\nend\n```","ref":"readme.html#3-use-feature-flippers-in-your-code"},{"type":"extras","title":"Environment Behavior - FeatureFlipper","doc":"","ref":"readme.html#environment-behavior"},{"type":"extras","title":"Non-production environments (dev, test, staging) - FeatureFlipper","doc":"- Features are **enabled by default** unless `force_disable: true` is set\n- Consul is not required to be available\n- Graceful fallback to default values","ref":"readme.html#non-production-environments-dev-test-staging"},{"type":"extras","title":"Production environment - FeatureFlipper","doc":"- Features are **controlled by Consul KV data**\n- Consul connectivity is required for accurate feature flag values\n- Supports hostname-specific feature flags","ref":"readme.html#production-environment"},{"type":"extras","title":"Consul Integration - FeatureFlipper","doc":"","ref":"readme.html#consul-integration"},{"type":"extras","title":"Path Structure - FeatureFlipper","doc":"The library automatically builds Consul paths based on your configuration:\n\n- **Production**: `{consul_kv_path}/feature_flippers[_{version_suffix}]`\n- **Non-production**: `{consul_kv_path}/feature-flippers[_{version_suffix}]`","ref":"readme.html#path-structure"},{"type":"extras","title":"Hostname Targeting - FeatureFlipper","doc":"You can target specific hostnames by appending the hostname to the key:\n\n```\n# General key\nmy_feature_flag: true\n\n# Hostname-specific key (takes precedence)\nmy_feature_flag_server1: false\n```","ref":"readme.html#hostname-targeting"},{"type":"extras","title":"Data Format - FeatureFlipper","doc":"Consul values can be stored as:\n- JSON booleans: `true`, `false`\n- String booleans: `\"true\"`, `\"false\"`","ref":"readme.html#data-format"},{"type":"extras","title":"API Reference - FeatureFlipper","doc":"","ref":"readme.html#api-reference"},{"type":"extras","title":"Main Interface - FeatureFlipper","doc":"```elixir\n# Check if a feature is enabled\nFeatureFlipper.enabled?(:my_feature)\nFeatureFlipper.enabled?(\"my_feature\")\n\n# Reload configuration from Consul\nFeatureFlipper.reload_configuration()\n\n# Get all feature flags and their values\nFeatureFlipper.get_all_flags()\n```","ref":"readme.html#main-interface"},{"type":"extras","title":"Definition Options - FeatureFlipper","doc":"When defining feature flippers, you can specify:\n\n- `:deadline` - Date when the feature should be removed (Date struct)\n- `:description` - Human-readable description of the feature\n- `:force_disable` - Force disable in non-production environments (boolean, default: false)\n- `:key` - Custom Consul key (string, optional - defaults to the flipper name)","ref":"readme.html#definition-options"},{"type":"extras","title":"Deadline Management - FeatureFlipper","doc":"","ref":"readme.html#deadline-management"},{"type":"extras","title":"TODO: This is not yet properly implemented - FeatureFlipper","doc":"The library automatically tracks feature flipper deadlines:\n\n```elixir\n# Check for overdue features\nwarnings = FeatureFlipper.check_deadlines()\n# Returns: [\"Feature 'old_feature' is past its deadline of 2024-01-01\"]\n\n# This can be integrated into your monitoring/alerting system\n```","ref":"readme.html#todo-this-is-not-yet-properly-implemented"},{"type":"extras","title":"Error Handling - FeatureFlipper","doc":"The library provides comprehensive error handling:\n\n- **fail fast**: fail fast if consul is not available\n- **Invalid data**: Graceful parsing with sensible defaults\n- **Configuration errors**: Clear error messages and logging","ref":"readme.html#error-handling"},{"type":"extras","title":"Performance - FeatureFlipper","doc":"- **In-memory caching**: Fast access to feature flag values\n- **Minimal overhead**: Efficient caching layer with `:persistent_term`\n- **Batch loading**: Loads all configuration at startup","ref":"readme.html#performance"},{"type":"extras","title":"Testing - FeatureFlipper","doc":"The library includes comprehensive test coverage and provides mocking capabilities for testing your feature-flagged code.","ref":"readme.html#testing"},{"type":"extras","title":"Contributing - FeatureFlipper","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n3. Commit your changes (`git commit -m 'Add amazing feature'`)\n4. Push to the branch (`git push origin feature/amazing-feature`)\n5. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - FeatureFlipper","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}